# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/maintenance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/k8s/v1/maintenance.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1bgoogle/type/dayofweek.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dyandex/cloud/validation.proto\"\x89\x02\n\x11MaintenanceWindow\x12@\n\x07\x61nytime\x18\x01 \x01(\x0b\x32-.yandex.cloud.k8s.v1.AnytimeMaintenanceWindowH\x00\x12O\n\x18\x64\x61ily_maintenance_window\x18\x02 \x01(\x0b\x32+.yandex.cloud.k8s.v1.DailyMaintenanceWindowH\x00\x12Q\n\x19weekly_maintenance_window\x18\x03 \x01(\x0b\x32,.yandex.cloud.k8s.v1.WeeklyMaintenanceWindowH\x00\x42\x0e\n\x06policy\x12\x04\xc0\xc1\x31\x01\"\x1a\n\x18\x41nytimeMaintenanceWindow\"\x83\x01\n\x16\x44\x61ilyMaintenanceWindow\x12\x30\n\nstart_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31h-24h\"\xb7\x01\n\x1b\x44\x61ysOfWeekMaintenanceWindow\x12-\n\x04\x64\x61ys\x18\x01 \x03(\x0e\x32\x16.google.type.DayOfWeekB\x07\x82\xc8\x31\x03\x31-7\x12\x30\n\nstart_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\x12\x37\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31h-24h\"j\n\x17WeeklyMaintenanceWindow\x12O\n\x0c\x64\x61ys_of_week\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.k8s.v1.DaysOfWeekMaintenanceWindowB\x07\x82\xc8\x31\x03\x31-7BV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.maintenance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _MAINTENANCEWINDOW.oneofs_by_name['policy']._options = None
  _MAINTENANCEWINDOW.oneofs_by_name['policy']._serialized_options = b'\300\3011\001'
  _DAILYMAINTENANCEWINDOW.fields_by_name['start_time']._options = None
  _DAILYMAINTENANCEWINDOW.fields_by_name['start_time']._serialized_options = b'\350\3071\001'
  _DAILYMAINTENANCEWINDOW.fields_by_name['duration']._options = None
  _DAILYMAINTENANCEWINDOW.fields_by_name['duration']._serialized_options = b'\372\3071\0061h-24h'
  _DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['days']._options = None
  _DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['days']._serialized_options = b'\202\3101\0031-7'
  _DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['start_time']._options = None
  _DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['start_time']._serialized_options = b'\350\3071\001'
  _DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['duration']._options = None
  _DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['duration']._serialized_options = b'\372\3071\0061h-24h'
  _WEEKLYMAINTENANCEWINDOW.fields_by_name['days_of_week']._options = None
  _WEEKLYMAINTENANCEWINDOW.fields_by_name['days_of_week']._serialized_options = b'\202\3101\0031-7'
  _globals['_MAINTENANCEWINDOW']._serialized_start=184
  _globals['_MAINTENANCEWINDOW']._serialized_end=449
  _globals['_ANYTIMEMAINTENANCEWINDOW']._serialized_start=451
  _globals['_ANYTIMEMAINTENANCEWINDOW']._serialized_end=477
  _globals['_DAILYMAINTENANCEWINDOW']._serialized_start=480
  _globals['_DAILYMAINTENANCEWINDOW']._serialized_end=611
  _globals['_DAYSOFWEEKMAINTENANCEWINDOW']._serialized_start=614
  _globals['_DAYSOFWEEKMAINTENANCEWINDOW']._serialized_end=797
  _globals['_WEEKLYMAINTENANCEWINDOW']._serialized_start=799
  _globals['_WEEKLYMAINTENANCEWINDOW']._serialized_end=905
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    THREAD_ID_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    id: builtins.str
    thread_id: builtins.str
    created_by: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def author(self) -> global___Author: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def content(self) -> global___MessageContent: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        thread_id: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        author: global___Author | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content: global___MessageContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "content", b"content", "created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "content", b"content", "created_at", b"created_at", "created_by", b"created_by", "id", b"id", "labels", b"labels", "thread_id", b"thread_id"]) -> None: ...

global___Message = Message

@typing.final
class MessageContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContentPart]: ...
    def __init__(
        self,
        *,
        content: collections.abc.Iterable[global___ContentPart] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

global___MessageContent = MessageContent

@typing.final
class MessageData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTHOR_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def author(self) -> global___Author: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def content(self) -> global___MessageContent: ...
    def __init__(
        self,
        *,
        author: global___Author | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content: global___MessageContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "content", b"content", "labels", b"labels"]) -> None: ...

global___MessageData = MessageData

@typing.final
class Text(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

global___Text = Text

@typing.final
class ContentPart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___Text: ...
    def __init__(
        self,
        *,
        text: global___Text | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["PartType", b"PartType", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["PartType", b"PartType", "text", b"text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["PartType", b"PartType"]) -> typing.Literal["text"] | None: ...

global___ContentPart = ContentPart

@typing.final
class Author(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    role: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        role: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "role", b"role"]) -> None: ...

global___Author = Author



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/chart_widget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.monitoring.v3 import downsampling_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_downsampling__pb2
from yandex.cloud.monitoring.v3 import unit_format_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/monitoring/v3/chart_widget.proto\x12\x1ayandex.cloud.monitoring.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/monitoring/v3/downsampling.proto\x1a,yandex/cloud/monitoring/v3/unit_format.proto\"\xef\"\n\x0b\x43hartWidget\x12\n\n\x02id\x18\x01 \x01(\t\x12@\n\x07queries\x18\x02 \x01(\x0b\x32/.yandex.cloud.monitoring.v3.ChartWidget.Queries\x12]\n\x16visualization_settings\x18\x03 \x01(\x0b\x32=.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings\x12Q\n\x10series_overrides\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides\x12X\n\x14name_hiding_settings\x18\x05 \x01(\x0b\x32:.yandex.cloud.monitoring.v3.ChartWidget.NameHidingSettings\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x16\n\x0e\x64isplay_legend\x18\x08 \x01(\x08\x12\x46\n\x06\x66reeze\x18\t \x01(\x0e\x32\x36.yandex.cloud.monitoring.v3.ChartWidget.FreezeDuration\x12\x46\n\x06repeat\x18\n \x01(\x0b\x32\x36.yandex.cloud.monitoring.v3.ChartWidget.RepeatSettings\x1a\xdc\x01\n\x07Queries\x12G\n\x07targets\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.monitoring.v3.ChartWidget.Queries.Target\x12>\n\x0c\x64ownsampling\x18\x02 \x01(\x0b\x32(.yandex.cloud.monitoring.v3.Downsampling\x1aH\n\x06Target\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\ttext_mode\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a\xc4\x14\n\x15VisualizationSettings\x12]\n\x04type\x18\x01 \x01(\x0e\x32O.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.VisualizationType\x12\x11\n\tnormalize\x18\x02 \x01(\x08\x12^\n\x0binterpolate\x18\x03 \x01(\x0e\x32I.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Interpolate\x12\x64\n\x0b\x61ggregation\x18\x04 \x01(\x0e\x32O.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.SeriesAggregation\x12p\n\x15\x63olor_scheme_settings\x18\x05 \x01(\x0b\x32Q.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings\x12g\n\x10heatmap_settings\x18\x06 \x01(\x0b\x32M.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings\x12\x63\n\x0eyaxis_settings\x18\x07 \x01(\x0b\x32K.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisSettings\x12\r\n\x05title\x18\x08 \x01(\t\x12\x13\n\x0bshow_labels\x18\t \x01(\x08\x1a\xb2\x05\n\x13\x43olorSchemeSettings\x12{\n\tautomatic\x18\x01 \x01(\x0b\x32\x66.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorSchemeH\x00\x12y\n\x08standard\x18\x02 \x01(\x0b\x32\x65.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorSchemeH\x00\x12y\n\x08gradient\x18\x03 \x01(\x0b\x32\x65.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorSchemeH\x00\x12q\n\x04hash\x18\x04 \x01(\x0b\x32\x61.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorSchemeH\x00\x1a\x16\n\x14\x41utomaticColorScheme\x1a\x15\n\x13StandardColorScheme\x1ai\n\x13GradientColorScheme\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\t\x1a\x11\n\x0fHashColorSchemeB\x08\n\x06scheme\x1a\x65\n\x0fHeatmapSettings\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\t\x1a\xf4\x01\n\x05Yaxis\x12U\n\x04type\x18\x01 \x01(\x0e\x32G.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03min\x18\x03 \x01(\t\x12\x0b\n\x03max\x18\x04 \x01(\t\x12;\n\x0bunit_format\x18\x05 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\x12.\n\tprecision\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\xb6\x01\n\rYaxisSettings\x12Q\n\x04left\x18\x01 \x01(\x0b\x32\x43.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis\x12R\n\x05right\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis\"\xae\x02\n\x11VisualizationType\x12\"\n\x1eVISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17VISUALIZATION_TYPE_LINE\x10\x01\x12\x1c\n\x18VISUALIZATION_TYPE_STACK\x10\x02\x12\x1d\n\x19VISUALIZATION_TYPE_COLUMN\x10\x03\x12\x1d\n\x19VISUALIZATION_TYPE_POINTS\x10\x04\x12\x1a\n\x16VISUALIZATION_TYPE_PIE\x10\x05\x12\x1b\n\x17VISUALIZATION_TYPE_BARS\x10\x06\x12#\n\x1fVISUALIZATION_TYPE_DISTRIBUTION\x10\x07\x12\x1e\n\x1aVISUALIZATION_TYPE_HEATMAP\x10\x08\"o\n\x0bInterpolate\x12\x1b\n\x17INTERPOLATE_UNSPECIFIED\x10\x00\x12\x16\n\x12INTERPOLATE_LINEAR\x10\x01\x12\x14\n\x10INTERPOLATE_LEFT\x10\x02\x12\x15\n\x11INTERPOLATE_RIGHT\x10\x03\"Z\n\tYaxisType\x12\x1a\n\x16YAXIS_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11YAXIS_TYPE_LINEAR\x10\x01\x12\x1a\n\x16YAXIS_TYPE_LOGARITHMIC\x10\x02\"\xc4\x01\n\x11SeriesAggregation\x12\"\n\x1eSERIES_AGGREGATION_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERIES_AGGREGATION_AVG\x10\x01\x12\x1a\n\x16SERIES_AGGREGATION_MIN\x10\x02\x12\x1a\n\x16SERIES_AGGREGATION_MAX\x10\x03\x12\x1b\n\x17SERIES_AGGREGATION_LAST\x10\x04\x12\x1a\n\x16SERIES_AGGREGATION_SUM\x10\x05\x1a\x80\x06\n\x0fSeriesOverrides\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\x16\n\x0ctarget_index\x18\x02 \x01(\tH\x00\x12`\n\x08settings\x18\x03 \x01(\x0b\x32N.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings\x1a\x9a\x02\n\x16SeriesOverrideSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12]\n\x04type\x18\x03 \x01(\x0e\x32O.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesVisualizationType\x12\x12\n\nstack_name\x18\x04 \x01(\t\x12\x11\n\tgrow_down\x18\x05 \x01(\x08\x12]\n\x0eyaxis_position\x18\x06 \x01(\x0e\x32\x45.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.YaxisPosition\"b\n\rYaxisPosition\x12\x1e\n\x1aYAXIS_POSITION_UNSPECIFIED\x10\x00\x12\x17\n\x13YAXIS_POSITION_LEFT\x10\x01\x12\x18\n\x14YAXIS_POSITION_RIGHT\x10\x02\"\xd9\x01\n\x17SeriesVisualizationType\x12)\n%SERIES_VISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1eSERIES_VISUALIZATION_TYPE_LINE\x10\x01\x12#\n\x1fSERIES_VISUALIZATION_TYPE_STACK\x10\x02\x12$\n SERIES_VISUALIZATION_TYPE_COLUMN\x10\x03\x12$\n SERIES_VISUALIZATION_TYPE_POINTS\x10\x04\x42\x06\n\x04type\x1a\x35\n\x12NameHidingSettings\x12\x10\n\x08positive\x18\x01 \x01(\x08\x12\r\n\x05names\x18\x02 \x03(\t\x1a>\n\x0eRepeatSettings\x12\x11\n\trepeat_by\x18\x01 \x03(\t\x12\x19\n\x11max_charts_in_row\x18\x02 \x01(\x03\"\x99\x01\n\x0e\x46reezeDuration\x12\x1f\n\x1b\x46REEZE_DURATION_UNSPECIFIED\x10\x00\x12\x18\n\x14\x46REEZE_DURATION_HOUR\x10\x01\x12\x17\n\x13\x46REEZE_DURATION_DAY\x10\x02\x12\x18\n\x14\x46REEZE_DURATION_WEEK\x10\x03\x12\x19\n\x15\x46REEZE_DURATION_MONTH\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.chart_widget_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_CHARTWIDGET']._serialized_start=203
  _globals['_CHARTWIDGET']._serialized_end=4666
  _globals['_CHARTWIDGET_QUERIES']._serialized_start=769
  _globals['_CHARTWIDGET_QUERIES']._serialized_end=989
  _globals['_CHARTWIDGET_QUERIES_TARGET']._serialized_start=917
  _globals['_CHARTWIDGET_QUERIES_TARGET']._serialized_end=989
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS']._serialized_start=992
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS']._serialized_end=3620
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS']._serialized_start=1686
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS']._serialized_end=2376
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME']._serialized_start=2195
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME']._serialized_end=2217
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME']._serialized_start=2219
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME']._serialized_end=2240
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME']._serialized_start=2242
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME']._serialized_end=2347
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_HASHCOLORSCHEME']._serialized_start=2349
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_HASHCOLORSCHEME']._serialized_end=2366
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS']._serialized_start=2378
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS']._serialized_end=2479
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS']._serialized_start=2482
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS']._serialized_end=2726
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS']._serialized_start=2729
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS']._serialized_end=2911
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE']._serialized_start=2914
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE']._serialized_end=3216
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE']._serialized_start=3218
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE']._serialized_end=3329
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE']._serialized_start=3331
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE']._serialized_end=3421
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION']._serialized_start=3424
  _globals['_CHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION']._serialized_end=3620
  _globals['_CHARTWIDGET_SERIESOVERRIDES']._serialized_start=3623
  _globals['_CHARTWIDGET_SERIESOVERRIDES']._serialized_end=4391
  _globals['_CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS']._serialized_start=3781
  _globals['_CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS']._serialized_end=4063
  _globals['_CHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION']._serialized_start=4065
  _globals['_CHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION']._serialized_end=4163
  _globals['_CHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE']._serialized_start=4166
  _globals['_CHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE']._serialized_end=4383
  _globals['_CHARTWIDGET_NAMEHIDINGSETTINGS']._serialized_start=4393
  _globals['_CHARTWIDGET_NAMEHIDINGSETTINGS']._serialized_end=4446
  _globals['_CHARTWIDGET_REPEATSETTINGS']._serialized_start=4448
  _globals['_CHARTWIDGET_REPEATSETTINGS']._serialized_end=4510
  _globals['_CHARTWIDGET_FREEZEDURATION']._serialized_start=4513
  _globals['_CHARTWIDGET_FREEZEDURATION']._serialized_end=4666
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/customer_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.billing.v1 import customer_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_customer__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/billing/v1/customer_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/billing/v1/customer.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"}\n\x14ListCustomersRequest\x12!\n\x0breseller_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100J\x04\x08\x02\x10\x03\"f\n\x15ListCustomersResponse\x12\x34\n\tcustomers\x18\x01 \x03(\x0b\x32!.yandex.cloud.billing.v1.Customer\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xad\x01\n\x15InviteCustomerRequest\x12!\n\x0breseller_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x10invitation_email\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\x06person\x18\x04 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CustomerPersonB\x04\xe8\xc7\x31\x01\"\x9b\x01\n#CreateResellerServedCustomerRequest\x12!\n\x0breseller_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\x06person\x18\x03 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CustomerPersonB\x04\xe8\xc7\x31\x01\"<\n\x17\x41\x63tivateCustomerRequest\x12!\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\";\n\x16SuspendCustomerRequest\x12!\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x10\x43ustomerMetadata\x12\x13\n\x0breseller_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t2\x85\x07\n\x0f\x43ustomerService\x12\x84\x01\n\x04List\x12-.yandex.cloud.billing.v1.ListCustomersRequest\x1a..yandex.cloud.billing.v1.ListCustomersResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/billing/v1/customers\x12\xa4\x01\n\x06Invite\x12..yandex.cloud.billing.v1.InviteCustomerRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x1c\n\x10\x43ustomerMetadata\x12\x08\x43ustomer\x82\xd3\xe4\x93\x02!\"\x1c/billing/v1/customers:invite:\x01*\x12\xd6\x01\n\x14\x43reateResellerServed\x12<.yandex.cloud.billing.v1.CreateResellerServedCustomerRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*\x1c\n\x10\x43ustomerMetadata\x12\x08\x43ustomer\x82\xd3\xe4\x93\x02\x37\"2/billing/v1/customers:createResellerServedCustomer:\x01*\x12\xb5\x01\n\x08\x41\x63tivate\x12\x30.yandex.cloud.billing.v1.ActivateCustomerRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*\x1c\n\x10\x43ustomerMetadata\x12\x08\x43ustomer\x82\xd3\xe4\x93\x02.\",/billing/v1/customers/{customer_id}:activate\x12\xb2\x01\n\x07Suspend\x12/.yandex.cloud.billing.v1.SuspendCustomerRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*\x1c\n\x10\x43ustomerMetadata\x12\x08\x43ustomer\x82\xd3\xe4\x93\x02-\"+/billing/v1/customers/{customer_id}:suspendBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.customer_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _LISTCUSTOMERSREQUEST.fields_by_name['reseller_id']._options = None
  _LISTCUSTOMERSREQUEST.fields_by_name['reseller_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCUSTOMERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCUSTOMERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCUSTOMERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCUSTOMERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _INVITECUSTOMERREQUEST.fields_by_name['reseller_id']._options = None
  _INVITECUSTOMERREQUEST.fields_by_name['reseller_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _INVITECUSTOMERREQUEST.fields_by_name['name']._options = None
  _INVITECUSTOMERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _INVITECUSTOMERREQUEST.fields_by_name['invitation_email']._options = None
  _INVITECUSTOMERREQUEST.fields_by_name['invitation_email']._serialized_options = b'\350\3071\001'
  _INVITECUSTOMERREQUEST.fields_by_name['person']._options = None
  _INVITECUSTOMERREQUEST.fields_by_name['person']._serialized_options = b'\350\3071\001'
  _CREATERESELLERSERVEDCUSTOMERREQUEST.fields_by_name['reseller_id']._options = None
  _CREATERESELLERSERVEDCUSTOMERREQUEST.fields_by_name['reseller_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATERESELLERSERVEDCUSTOMERREQUEST.fields_by_name['name']._options = None
  _CREATERESELLERSERVEDCUSTOMERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CREATERESELLERSERVEDCUSTOMERREQUEST.fields_by_name['person']._options = None
  _CREATERESELLERSERVEDCUSTOMERREQUEST.fields_by_name['person']._serialized_options = b'\350\3071\001'
  _ACTIVATECUSTOMERREQUEST.fields_by_name['customer_id']._options = None
  _ACTIVATECUSTOMERREQUEST.fields_by_name['customer_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _SUSPENDCUSTOMERREQUEST.fields_by_name['customer_id']._options = None
  _SUSPENDCUSTOMERREQUEST.fields_by_name['customer_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CUSTOMERSERVICE.methods_by_name['List']._options = None
  _CUSTOMERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/billing/v1/customers'
  _CUSTOMERSERVICE.methods_by_name['Invite']._options = None
  _CUSTOMERSERVICE.methods_by_name['Invite']._serialized_options = b'\262\322*\034\n\020CustomerMetadata\022\010Customer\202\323\344\223\002!\"\034/billing/v1/customers:invite:\001*'
  _CUSTOMERSERVICE.methods_by_name['CreateResellerServed']._options = None
  _CUSTOMERSERVICE.methods_by_name['CreateResellerServed']._serialized_options = b'\262\322*\034\n\020CustomerMetadata\022\010Customer\202\323\344\223\0027\"2/billing/v1/customers:createResellerServedCustomer:\001*'
  _CUSTOMERSERVICE.methods_by_name['Activate']._options = None
  _CUSTOMERSERVICE.methods_by_name['Activate']._serialized_options = b'\262\322*\034\n\020CustomerMetadata\022\010Customer\202\323\344\223\002.\",/billing/v1/customers/{customer_id}:activate'
  _CUSTOMERSERVICE.methods_by_name['Suspend']._options = None
  _CUSTOMERSERVICE.methods_by_name['Suspend']._serialized_options = b'\262\322*\034\n\020CustomerMetadata\022\010Customer\202\323\344\223\002-\"+/billing/v1/customers/{customer_id}:suspend'
  _globals['_LISTCUSTOMERSREQUEST']._serialized_start=250
  _globals['_LISTCUSTOMERSREQUEST']._serialized_end=375
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_start=377
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_end=479
  _globals['_INVITECUSTOMERREQUEST']._serialized_start=482
  _globals['_INVITECUSTOMERREQUEST']._serialized_end=655
  _globals['_CREATERESELLERSERVEDCUSTOMERREQUEST']._serialized_start=658
  _globals['_CREATERESELLERSERVEDCUSTOMERREQUEST']._serialized_end=813
  _globals['_ACTIVATECUSTOMERREQUEST']._serialized_start=815
  _globals['_ACTIVATECUSTOMERREQUEST']._serialized_end=875
  _globals['_SUSPENDCUSTOMERREQUEST']._serialized_start=877
  _globals['_SUSPENDCUSTOMERREQUEST']._serialized_end=936
  _globals['_CUSTOMERMETADATA']._serialized_start=938
  _globals['_CUSTOMERMETADATA']._serialized_end=998
  _globals['_CUSTOMERSERVICE']._serialized_start=1001
  _globals['_CUSTOMERSERVICE']._serialized_end=1902
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PurgeCacheRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to perform purge operation on."""
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Set of paths:
        Paths of the files to remove from the cache.

        You may use asterisk (`*`) as a wildcard character that substitutes any number of characters.

        If an empty array of paths is specified (`"paths": []`), the cache is purged entirely.
        """

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["paths", b"paths", "resource_id", b"resource_id"]) -> None: ...

global___PurgeCacheRequest = PurgeCacheRequest

@typing.final
class PurgeCacheMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___PurgeCacheMetadata = PurgeCacheMetadata

@typing.final
class PrefetchCacheRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to perform prefetch operation on."""
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Set of paths to prefetch."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["paths", b"paths", "resource_id", b"resource_id"]) -> None: ...

global___PrefetchCacheRequest = PrefetchCacheRequest

@typing.final
class PrefetchCacheMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___PrefetchCacheMetadata = PrefetchCacheMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.agent.v1.job_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class JobServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ClaimStatus: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.ClaimJobStatusRequest,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.ClaimJobStatusResponse,
    ]
    """Claims status for the specified job."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.GetJobRequest,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.Job,
    ]
    """Returns the job for the specified agent."""

    GetSignal: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.JobSignalRequest,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.JobSignalResponse,
    ]
    """Returns the signal for the specified job."""

    GetTransientFile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.GetJobTransientFile,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.File,
    ]

class JobServiceAsyncStub:
    ClaimStatus: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.ClaimJobStatusRequest,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.ClaimJobStatusResponse,
    ]
    """Claims status for the specified job."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.GetJobRequest,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.Job,
    ]
    """Returns the job for the specified agent."""

    GetSignal: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.JobSignalRequest,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.JobSignalResponse,
    ]
    """Returns the signal for the specified job."""

    GetTransientFile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.GetJobTransientFile,
        yandex.cloud.loadtesting.agent.v1.job_service_pb2.File,
    ]

class JobServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ClaimStatus(
        self,
        request: yandex.cloud.loadtesting.agent.v1.job_service_pb2.ClaimJobStatusRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.agent.v1.job_service_pb2.ClaimJobStatusResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.agent.v1.job_service_pb2.ClaimJobStatusResponse]]:
        """Claims status for the specified job."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.loadtesting.agent.v1.job_service_pb2.GetJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.agent.v1.job_service_pb2.Job, collections.abc.Awaitable[yandex.cloud.loadtesting.agent.v1.job_service_pb2.Job]]:
        """Returns the job for the specified agent."""

    @abc.abstractmethod
    def GetSignal(
        self,
        request: yandex.cloud.loadtesting.agent.v1.job_service_pb2.JobSignalRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.agent.v1.job_service_pb2.JobSignalResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.agent.v1.job_service_pb2.JobSignalResponse]]:
        """Returns the signal for the specified job."""

    @abc.abstractmethod
    def GetTransientFile(
        self,
        request: yandex.cloud.loadtesting.agent.v1.job_service_pb2.GetJobTransientFile,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.agent.v1.job_service_pb2.File, collections.abc.Awaitable[yandex.cloud.loadtesting.agent.v1.job_service_pb2.File]]: ...

def add_JobServiceServicer_to_server(servicer: JobServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.test.details_pb2
import yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2
import yandex.cloud.loadtesting.api.v1.test.test_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    TEST_DETAILS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a test in."""
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2.SingleAgentConfiguration]:
        """Test configuration associated with agents on which they will be executed.
        In case of multiple configurations, a multitest will be created.
        """

    @property
    def test_details(self) -> yandex.cloud.loadtesting.api.v1.test.details_pb2.Details:
        """Test details. Name, tags etc."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        configurations: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2.SingleAgentConfiguration] | None = ...,
        test_details: yandex.cloud.loadtesting.api.v1.test.details_pb2.Details | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["test_details", b"test_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["configurations", b"configurations", "folder_id", b"folder_id", "test_details", b"test_details"]) -> None: ...

global___CreateTestRequest = CreateTestRequest

@typing.final
class CreateTestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test that is being created."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___CreateTestMetadata = CreateTestMetadata

@typing.final
class GetTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test to return."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___GetTestRequest = GetTestRequest

@typing.final
class StopTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test to stop."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___StopTestRequest = StopTestRequest

@typing.final
class StopTestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test that is being stopped."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___StopTestMetadata = StopTestMetadata

@typing.final
class DeleteTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test to delete."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___DeleteTestRequest = DeleteTestRequest

@typing.final
class DeleteTestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test that is being deleted."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___DeleteTestMetadata = DeleteTestMetadata

@typing.final
class ListTestsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list tests in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListTestsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the 
    [ListTestsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters tests listed in the response.

    The filter expression may contain multiple field expressions joined by `AND`.
    The field expression must specify:
    1. The field name.
    2. An operator:
       - `=`, `!=`, `<`, `<=`, `>`, `>=`, `CONTAINS`, `:` for single values.
       - `IN` or `NOT IN` for lists of values.
    3. The value. String values must be encosed in `"`, boolean values are {`true`, `false`}, timestamp values in ISO-8601.

    Currently supported fields:
    - `id` [yandex.cloud.loadtesting.api.v1.test.Test.id]
      - operators: `=`, `!=`, `IN`, `NOT IN`
    - `details.name` [yandex.cloud.loadtesting.api.v1.test.Details.name]
      - operators: `=`, `!=`, `IN`, `NOT IN`, `CONTAINS`
    - `details.tags.<TAG_NAME>` [yandex.cloud.loadtesting.api.v1.test.Details.tags]
      - operators: `:`
    - `summary.status` [yandex.cloud.loadtesting.api.v1.test.Summary.status]
      - operators: `=`, `!=`, `IN`, `NOT IN`
    - `summary.is_finished` [yandex.cloud.loadtesting.api.v1.test.Summary.is_finished]
      - operators: `=`
    - `summary.created_at` [yandex.cloud.loadtesting.api.v1.test.Summary.created_at]
      - operators: `<`, `<=`, `>`, `>=`
    - `summary.created_by` [yandex.cloud.loadtesting.api.v1.test.Summary.created_by]
      - operators: `=`, `!=`, `IN`, `NOT IN`

    Examples: 
    - `summary.status IN ("DONE", "ERROR") AND details.tags.author:"yandex"`
    - `summary.is_finished = true AND details.name CONTAINS "nightly-test"`
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListTestsRequest = ListTestsRequest

@typing.final
class ListTestsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TESTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListTestsRequest.page_size], use `next_page_token` as the value
    for the [ListTestsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def tests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.test.test_pb2.Test]:
        """List of tests in the specified folder."""

    def __init__(
        self,
        *,
        tests: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.test.test_pb2.Test] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "tests", b"tests"]) -> None: ...

global___ListTestsResponse = ListTestsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ServerRole:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ServerRoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ServerRole.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SERVER_ROLE_UNSPECIFIED: _ServerRole.ValueType  # 0
    MDB_MONITOR: _ServerRole.ValueType  # 1
    """Effectively grants VIEW SERVER STATE to the login.

    That gives an ability to use various dynamic management views to monitor server state, including Activity Monitor tool that is built-in into SSMS.

    No intrusive actions are allowed, so this is pretty safe to grant.
    """

class ServerRole(_ServerRole, metaclass=_ServerRoleEnumTypeWrapper):
    """Set of server roles."""

SERVER_ROLE_UNSPECIFIED: ServerRole.ValueType  # 0
MDB_MONITOR: ServerRole.ValueType  # 1
"""Effectively grants VIEW SERVER STATE to the login.

That gives an ability to use various dynamic management views to monitor server state, including Activity Monitor tool that is built-in into SSMS.

No intrusive actions are allowed, so this is pretty safe to grant.
"""
global___ServerRole = ServerRole

@typing.final
class User(google.protobuf.message.Message):
    """An SQL Server user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    SERVER_ROLES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SQL Server user."""
    cluster_id: builtins.str
    """ID of the SQL Server cluster the user belongs to."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user."""

    @property
    def server_roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___ServerRole.ValueType]:
        """Set of server roles granted to the login."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        server_roles: collections.abc.Iterable[global___ServerRole.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "permissions", b"permissions", "server_roles", b"server_roles"]) -> None: ...

global___User = User

@typing.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Role:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Permission._Role.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ROLE_UNSPECIFIED: Permission._Role.ValueType  # 0
        DB_OWNER: Permission._Role.ValueType  # 1
        """Members of this fixed database role can perform all configuration and maintenance activities on a database and can also drop a database in SQL Server."""
        DB_SECURITYADMIN: Permission._Role.ValueType  # 2
        """Members of this fixed database role can modify role membership for custom roles only and manage permissions. They can potentially elevate their privileges and their actions should be monitored."""
        DB_ACCESSADMIN: Permission._Role.ValueType  # 3
        """Members of this fixed database role can add or remove access to a database for Windows logins, Windows groups, and SQL Server logins."""
        DB_BACKUPOPERATOR: Permission._Role.ValueType  # 4
        """Members of this fixed database role can back up the database."""
        DB_DDLADMIN: Permission._Role.ValueType  # 5
        """Members of this fixed database role can run any Data Definition Language (DDL) command in a database."""
        DB_DATAWRITER: Permission._Role.ValueType  # 6
        """Members of this fixed database role can add, delete, or change data in all user tables."""
        DB_DATAREADER: Permission._Role.ValueType  # 7
        """Members of this fixed database role can read all data from all user tables."""
        DB_DENYDATAWRITER: Permission._Role.ValueType  # 8
        """Members of this fixed database role cannot add, modify, or delete any data in the user tables within a database. A denial has a higher priority than a grant, so you can use this role to quickly restrict one's privileges without explicitly revoking permissions or roles."""
        DB_DENYDATAREADER: Permission._Role.ValueType  # 9
        """Members of this fixed database role cannot read any data in the user tables within a database. A denial has a higher priority than a grant, so you can use this role to quickly restrict one's privileges without explicitly revoking permissions or roles."""

    class Role(_Role, metaclass=_RoleEnumTypeWrapper):
        """Role granted to the user within the database."""

    ROLE_UNSPECIFIED: Permission.Role.ValueType  # 0
    DB_OWNER: Permission.Role.ValueType  # 1
    """Members of this fixed database role can perform all configuration and maintenance activities on a database and can also drop a database in SQL Server."""
    DB_SECURITYADMIN: Permission.Role.ValueType  # 2
    """Members of this fixed database role can modify role membership for custom roles only and manage permissions. They can potentially elevate their privileges and their actions should be monitored."""
    DB_ACCESSADMIN: Permission.Role.ValueType  # 3
    """Members of this fixed database role can add or remove access to a database for Windows logins, Windows groups, and SQL Server logins."""
    DB_BACKUPOPERATOR: Permission.Role.ValueType  # 4
    """Members of this fixed database role can back up the database."""
    DB_DDLADMIN: Permission.Role.ValueType  # 5
    """Members of this fixed database role can run any Data Definition Language (DDL) command in a database."""
    DB_DATAWRITER: Permission.Role.ValueType  # 6
    """Members of this fixed database role can add, delete, or change data in all user tables."""
    DB_DATAREADER: Permission.Role.ValueType  # 7
    """Members of this fixed database role can read all data from all user tables."""
    DB_DENYDATAWRITER: Permission.Role.ValueType  # 8
    """Members of this fixed database role cannot add, modify, or delete any data in the user tables within a database. A denial has a higher priority than a grant, so you can use this role to quickly restrict one's privileges without explicitly revoking permissions or roles."""
    DB_DENYDATAREADER: Permission.Role.ValueType  # 9
    """Members of this fixed database role cannot read any data in the user tables within a database. A denial has a higher priority than a grant, so you can use this role to quickly restrict one's privileges without explicitly revoking permissions or roles."""

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    """Name of the database the permission grants access to."""
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Permission.Role.ValueType]:
        """Roles granted to the user within the database."""

    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        roles: collections.abc.Iterable[global___Permission.Role.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_name", b"database_name", "roles", b"roles"]) -> None: ...

global___Permission = Permission

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    SERVER_ROLES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SQL Server user."""
    password: builtins.str
    """Password of the SQL Server user."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions to grant to the user."""

    @property
    def server_roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___ServerRole.ValueType]:
        """Set of server roles."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        server_roles: collections.abc.Iterable[global___ServerRole.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "password", b"password", "permissions", b"permissions", "server_roles", b"server_roles"]) -> None: ...

global___UserSpec = UserSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.elasticsearch.v1.extension_pb2
import yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ExtensionServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.GetExtensionRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension,
    ]
    """Returns the specified extension of Elasticsearch cluster."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse,
    ]
    """Returns the list of available extensions for the specified Elasticsearch cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.CreateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new extension version."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.UpdateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified extension."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.DeleteExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified extension."""

class ExtensionServiceAsyncStub:
    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.GetExtensionRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension,
    ]
    """Returns the specified extension of Elasticsearch cluster."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse,
    ]
    """Returns the list of available extensions for the specified Elasticsearch cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.CreateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new extension version."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.UpdateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified extension."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.DeleteExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified extension."""

class ExtensionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.GetExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension, collections.abc.Awaitable[yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension]]:
        """Returns the specified extension of Elasticsearch cluster."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse, collections.abc.Awaitable[yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse]]:
        """Returns the list of available extensions for the specified Elasticsearch cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.CreateExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates new extension version."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.UpdateExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified extension."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.DeleteExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified extension."""

def add_ExtensionServiceServicer_to_server(servicer: ExtensionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PromptTruncationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_PROMPT_TOKENS_FIELD_NUMBER: builtins.int
    @property
    def max_prompt_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        max_prompt_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_prompt_tokens", b"max_prompt_tokens"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_prompt_tokens", b"max_prompt_tokens"]) -> None: ...

global___PromptTruncationOptions = PromptTruncationOptions

@typing.final
class CompletionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_TOKENS_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    def __init__(
        self,
        *,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> None: ...

global___CompletionOptions = CompletionOptions

@typing.final
class SearchIndexTool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_IDS_FIELD_NUMBER: builtins.int
    MAX_NUM_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def search_index_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def max_num_results(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        search_index_ids: collections.abc.Iterable[builtins.str] | None = ...,
        max_num_results: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_num_results", b"max_num_results"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_num_results", b"max_num_results", "search_index_ids", b"search_index_ids"]) -> None: ...

global___SearchIndexTool = SearchIndexTool

@typing.final
class Tool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_FIELD_NUMBER: builtins.int
    @property
    def search_index(self) -> global___SearchIndexTool: ...
    def __init__(
        self,
        *,
        search_index: global___SearchIndexTool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolType", b"ToolType", "search_index", b"search_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolType", b"ToolType", "search_index", b"search_index"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolType", b"ToolType"]) -> typing.Literal["search_index"] | None: ...

global___Tool = Tool



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.clickhouse.v1.version_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListVersionsResponse.next_page_token] that can be used
    to get the next page of results in subsequent ListVersions requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token] to the [ListVersionsResponse.next_page_token] returned by a previous ListVersions
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListVersionsRequest = ListVersionsRequest

@typing.final
class ListVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListVersions requests,
    if the number of results is larger than [ListVersionsRequest.page_size] specified in the request.
    To get the next page, specify the value of [next_page_token] as a value for
    the [ListVersionsRequest.page_token] parameter in the next ListVerions request. Subsequent ListVersions
    requests will have their own [next_page_token] to continue paging through the results.
    """
    @property
    def version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.version_pb2.Version]:
        """Requested list of available versions."""

    def __init__(
        self,
        *,
        version: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.version_pb2.Version] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "version", b"version"]) -> None: ...

global___ListVersionsResponse = ListVersionsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/audio.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/speechsense/v1/audio.proto\x12\x1byandex.cloud.speechsense.v1\"\xe1\x01\n\x08RawAudio\x12K\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32\x33.yandex.cloud.speechsense.v1.RawAudio.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x03\x12\x1b\n\x13\x61udio_channel_count\x18\x03 \x01(\x03\"P\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41UDIO_ENCODING_LINEAR16_PCM\x10\x01\"\x8a\x02\n\x0e\x43ontainerAudio\x12\\\n\x14\x63ontainer_audio_type\x18\x01 \x01(\x0e\x32>.yandex.cloud.speechsense.v1.ContainerAudio.ContainerAudioType\"\x99\x01\n\x12\x43ontainerAudioType\x12$\n CONTAINER_AUDIO_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONTAINER_AUDIO_TYPE_WAV\x10\x01\x12!\n\x1d\x43ONTAINER_AUDIO_TYPE_OGG_OPUS\x10\x02\x12\x1c\n\x18\x43ONTAINER_AUDIO_TYPE_MP3\x10\x03\"\xa2\x01\n\rAudioMetadata\x12:\n\traw_audio\x18\x01 \x01(\x0b\x32%.yandex.cloud.speechsense.v1.RawAudioH\x00\x12\x46\n\x0f\x63ontainer_audio\x18\x02 \x01(\x0b\x32+.yandex.cloud.speechsense.v1.ContainerAudioH\x00\x42\r\n\x0b\x41udioFormat\"\x1a\n\nAudioChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\xa5\x01\n\x15\x41udioStreamingRequest\x12\x44\n\x0e\x61udio_metadata\x18\x01 \x01(\x0b\x32*.yandex.cloud.speechsense.v1.AudioMetadataH\x00\x12\x38\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\'.yandex.cloud.speechsense.v1.AudioChunkH\x00\x42\x0c\n\nAudioEvent\"\x8f\x01\n\x0c\x41udioRequest\x12\x42\n\x0e\x61udio_metadata\x18\x01 \x01(\x0b\x32*.yandex.cloud.speechsense.v1.AudioMetadata\x12;\n\naudio_data\x18\x02 \x01(\x0b\x32\'.yandex.cloud.speechsense.v1.AudioChunkBz\n\x1fyandex.cloud.api.speechsense.v1B\nAudioProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.audio_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\nAudioProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_RAWAUDIO']._serialized_start=73
  _globals['_RAWAUDIO']._serialized_end=298
  _globals['_RAWAUDIO_AUDIOENCODING']._serialized_start=218
  _globals['_RAWAUDIO_AUDIOENCODING']._serialized_end=298
  _globals['_CONTAINERAUDIO']._serialized_start=301
  _globals['_CONTAINERAUDIO']._serialized_end=567
  _globals['_CONTAINERAUDIO_CONTAINERAUDIOTYPE']._serialized_start=414
  _globals['_CONTAINERAUDIO_CONTAINERAUDIOTYPE']._serialized_end=567
  _globals['_AUDIOMETADATA']._serialized_start=570
  _globals['_AUDIOMETADATA']._serialized_end=732
  _globals['_AUDIOCHUNK']._serialized_start=734
  _globals['_AUDIOCHUNK']._serialized_end=760
  _globals['_AUDIOSTREAMINGREQUEST']._serialized_start=763
  _globals['_AUDIOSTREAMINGREQUEST']._serialized_end=928
  _globals['_AUDIOREQUEST']._serialized_start=931
  _globals['_AUDIOREQUEST']._serialized_end=1074
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.elasticsearch.v1.auth_pb2
import yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AuthServiceStub:
    """A set of methods for managing Elasticsearch Authentication resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListProviders: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.ListAuthProvidersRequest,
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.ListAuthProvidersResponse,
    ]
    """Retrieves the list of registered auth providers for Elasticsearch cluster."""

    GetProvider: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.GetAuthProviderRequest,
        yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider,
    ]
    """Returns registered auth provider by name."""

    AddProviders: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.AddAuthProvidersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds new auth providers to Elasticsearch cluster."""

    UpdateProviders: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.UpdateAuthProvidersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Replase the list of auth providers."""

    DeleteProviders: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.DeleteAuthProvidersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes auth providers from Elasticsearch cluster by name."""

    UpdateProvider: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.UpdateAuthProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates registered auth provider."""

    DeleteProvider: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.DeleteAuthProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes auth provider from Elasticsearch cluster by name."""

class AuthServiceAsyncStub:
    """A set of methods for managing Elasticsearch Authentication resources."""

    ListProviders: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.ListAuthProvidersRequest,
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.ListAuthProvidersResponse,
    ]
    """Retrieves the list of registered auth providers for Elasticsearch cluster."""

    GetProvider: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.GetAuthProviderRequest,
        yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider,
    ]
    """Returns registered auth provider by name."""

    AddProviders: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.AddAuthProvidersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds new auth providers to Elasticsearch cluster."""

    UpdateProviders: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.UpdateAuthProvidersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Replase the list of auth providers."""

    DeleteProviders: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.DeleteAuthProvidersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes auth providers from Elasticsearch cluster by name."""

    UpdateProvider: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.UpdateAuthProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates registered auth provider."""

    DeleteProvider: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.DeleteAuthProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes auth provider from Elasticsearch cluster by name."""

class AuthServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Elasticsearch Authentication resources."""

    @abc.abstractmethod
    def ListProviders(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.ListAuthProvidersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.ListAuthProvidersResponse, collections.abc.Awaitable[yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.ListAuthProvidersResponse]]:
        """Retrieves the list of registered auth providers for Elasticsearch cluster."""

    @abc.abstractmethod
    def GetProvider(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.GetAuthProviderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider, collections.abc.Awaitable[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider]]:
        """Returns registered auth provider by name."""

    @abc.abstractmethod
    def AddProviders(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.AddAuthProvidersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds new auth providers to Elasticsearch cluster."""

    @abc.abstractmethod
    def UpdateProviders(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.UpdateAuthProvidersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Replase the list of auth providers."""

    @abc.abstractmethod
    def DeleteProviders(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.DeleteAuthProvidersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes auth providers from Elasticsearch cluster by name."""

    @abc.abstractmethod
    def UpdateProvider(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.UpdateAuthProviderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates registered auth provider."""

    @abc.abstractmethod
    def DeleteProvider(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2.DeleteAuthProviderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes auth provider from Elasticsearch cluster by name."""

def add_AuthServiceServicer_to_server(servicer: AuthServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/analysis/speaker_statistics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1.analysis import statistics_common_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_statistics__common__pb2
from yandex.cloud.speechsense.v1.analysis import utterance_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_utterance__statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/speechsense/v1/analysis/speaker_statistics.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\x1a?yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto\"\xb3\x03\n\x11SpeakerStatistics\x12\x13\n\x0bspeaker_tag\x18\x01 \x01(\t\x12V\n\x13\x63omplete_statistics\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.speechsense.v1.analysis.UtteranceStatistics\x12X\n\x13words_per_utterance\x18\x03 \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatistics\x12Z\n\x15letters_per_utterance\x18\x04 \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatistics\x12\x17\n\x0futterance_count\x18\x05 \x01(\x03\x12\x62\n\x1dutterance_duration_estimation\x18\x06 \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatisticsB\x98\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x16SpeakerStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\026SpeakerStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_SPEAKERSTATISTICS']._serialized_start=231
  _globals['_SPEAKERSTATISTICS']._serialized_end=666
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadbalancer/v1/network_load_balancer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.loadbalancer.v1 import health_check_pb2 as yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_health__check__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/loadbalancer/v1/network_load_balancer.proto\x12\x1cyandex.cloud.loadbalancer.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a/yandex/cloud/loadbalancer/v1/health_check.proto\x1a\x1dyandex/cloud/validation.proto\"\xc0\x07\n\x13NetworkLoadBalancer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12M\n\x06labels\x18\x06 \x03(\x0b\x32=.yandex.cloud.loadbalancer.v1.NetworkLoadBalancer.LabelsEntry\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12H\n\x06status\x18\t \x01(\x0e\x32\x38.yandex.cloud.loadbalancer.v1.NetworkLoadBalancer.Status\x12\x44\n\x04type\x18\n \x01(\x0e\x32\x36.yandex.cloud.loadbalancer.v1.NetworkLoadBalancer.Type\x12[\n\x10session_affinity\x18\x0b \x01(\x0e\x32\x41.yandex.cloud.loadbalancer.v1.NetworkLoadBalancer.SessionAffinity\x12\x39\n\tlisteners\x18\x0c \x03(\x0b\x32&.yandex.cloud.loadbalancer.v1.Listener\x12Q\n\x16\x61ttached_target_groups\x18\r \x03(\x0b\x32\x31.yandex.cloud.loadbalancer.v1.AttachedTargetGroup\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08INACTIVE\x10\x07\"8\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x45XTERNAL\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\"M\n\x0fSessionAffinity\x12 \n\x1cSESSION_AFFINITY_UNSPECIFIED\x10\x00\x12\x18\n\x14\x43LIENT_IP_PORT_PROTO\x10\x01J\x04\x08\x08\x10\t\"\x85\x01\n\x13\x41ttachedTargetGroup\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12G\n\rhealth_checks\x18\x02 \x03(\x0b\x32).yandex.cloud.loadbalancer.v1.HealthCheckB\x05\x82\xc8\x31\x01\x31\"\x97\x02\n\x08Listener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x03\x12\x41\n\x08protocol\x18\x04 \x01(\x0e\x32/.yandex.cloud.loadbalancer.v1.Listener.Protocol\x12\x13\n\x0btarget_port\x18\x05 \x01(\x03\x12\x11\n\tsubnet_id\x18\x06 \x01(\t\x12;\n\nip_version\x18\x07 \x01(\x0e\x32\'.yandex.cloud.loadbalancer.v1.IpVersion\"6\n\x08Protocol\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\x07\n\x03UDP\x10\x02\"\xda\x01\n\x0bTargetState\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12@\n\x06status\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.loadbalancer.v1.TargetState.Status\"e\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07INITIAL\x10\x01\x12\x0b\n\x07HEALTHY\x10\x02\x12\r\n\tUNHEALTHY\x10\x03\x12\x0c\n\x08\x44RAINING\x10\x04\x12\x0c\n\x08INACTIVE\x10\x05*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02\x42q\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadbalancer.v1.network_load_balancer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancer'
  _NETWORKLOADBALANCER_LABELSENTRY._options = None
  _NETWORKLOADBALANCER_LABELSENTRY._serialized_options = b'8\001'
  _ATTACHEDTARGETGROUP.fields_by_name['target_group_id']._options = None
  _ATTACHEDTARGETGROUP.fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ATTACHEDTARGETGROUP.fields_by_name['health_checks']._options = None
  _ATTACHEDTARGETGROUP.fields_by_name['health_checks']._serialized_options = b'\202\3101\0011'
  _globals['_IPVERSION']._serialized_start=1805
  _globals['_IPVERSION']._serialized_end=1864
  _globals['_NETWORKLOADBALANCER']._serialized_start=204
  _globals['_NETWORKLOADBALANCER']._serialized_end=1164
  _globals['_NETWORKLOADBALANCER_LABELSENTRY']._serialized_start=847
  _globals['_NETWORKLOADBALANCER_LABELSENTRY']._serialized_end=892
  _globals['_NETWORKLOADBALANCER_STATUS']._serialized_start=894
  _globals['_NETWORKLOADBALANCER_STATUS']._serialized_end=1021
  _globals['_NETWORKLOADBALANCER_TYPE']._serialized_start=1023
  _globals['_NETWORKLOADBALANCER_TYPE']._serialized_end=1079
  _globals['_NETWORKLOADBALANCER_SESSIONAFFINITY']._serialized_start=1081
  _globals['_NETWORKLOADBALANCER_SESSIONAFFINITY']._serialized_end=1158
  _globals['_ATTACHEDTARGETGROUP']._serialized_start=1167
  _globals['_ATTACHEDTARGETGROUP']._serialized_end=1300
  _globals['_LISTENER']._serialized_start=1303
  _globals['_LISTENER']._serialized_end=1582
  _globals['_LISTENER_PROTOCOL']._serialized_start=1528
  _globals['_LISTENER_PROTOCOL']._serialized_end=1582
  _globals['_TARGETSTATE']._serialized_start=1585
  _globals['_TARGETSTATE']._serialized_end=1803
  _globals['_TARGETSTATE_STATUS']._serialized_start=1702
  _globals['_TARGETSTATE_STATUS']._serialized_end=1803
# @@protoc_insertion_point(module_scope)



from setuptools import find_packages, setup

packages = find_packages(".", include=["yandexcloud*", "yandex*"])

__version__ = "0.319.0"

with open("README.md") as file:
    README = file.read()

setup(
    name="yandexcloud",
    version=__version__,
    description="The Yandex.Cloud official SDK",
    url="https://github.com/yandex-cloud/python-sdk",
    author="Yandex LLC",
    author_email="cloud@support.yandex.ru",
    long_description=README,
    long_description_content_type="text/markdown",
    include_package_data=True,
    license="MIT",
    install_requires=[
        "cryptography>=41.0.7,<43",
        "grpcio>=1.64.0,<2",
        "protobuf>=4.25.3,<5",
        "googleapis-common-protos>=1.63.0,<2",
        "pyjwt>=2.8.0,<3",
        "requests>=2.32.3,<3",
        "six>=1.16.0,<2",
    ],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    tests_require=["pytest"],
    packages=packages,
    zip_safe=False,
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.dns.v1.dns_zone_pb2
import yandex.cloud.dns.v1.dns_zone_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DnsZoneServiceStub:
    """A set of methods for managing DNS zones."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.GetDnsZoneRequest,
        yandex.cloud.dns.v1.dns_zone_pb2.DnsZone,
    ]
    """Returns the specified DNS zone.

    To get the list of all available DNS zones, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZonesRequest,
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZonesResponse,
    ]
    """Retrieves the list of DNS zones in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.CreateDnsZoneRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a DNS zone in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateDnsZoneRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified DNS zone."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.DeleteDnsZoneRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified DNS zone."""

    GetRecordSet: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.GetDnsZoneRecordSetRequest,
        yandex.cloud.dns.v1.dns_zone_pb2.RecordSet,
    ]
    """Returns the specified record set."""

    ListRecordSets: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneRecordSetsRequest,
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneRecordSetsResponse,
    ]
    """Retrieves the list of record sets in the specified folder."""

    UpdateRecordSets: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateRecordSetsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Method with strict control for changing zone state. Returns error when:
    1. Deleted record is not found.
    2. Found record with matched type and name but different TTL or value.
    3. Attempted to add record with existing name and type.
    Deletions happen first. If a record with the same name and type exists in both lists,
    then the existing record will be deleted, and a new one added.
    """

    UpsertRecordSets: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpsertRecordSetsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Method without strict control for changing zone state. Nothing happens if deleted record doesn't exist.
    Deletes records that match all specified fields which allows to delete only specified records from a record set.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneOperationsRequest,
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneOperationsResponse,
    ]
    """Lists operations for the specified DNS zone."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified DNS zone."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified DNS zone."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified DNS zone."""

    UpdatePrivateNetworks: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateDnsZonePrivateNetworksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Atomically updates zone private networks"""

class DnsZoneServiceAsyncStub:
    """A set of methods for managing DNS zones."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.GetDnsZoneRequest,
        yandex.cloud.dns.v1.dns_zone_pb2.DnsZone,
    ]
    """Returns the specified DNS zone.

    To get the list of all available DNS zones, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZonesRequest,
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZonesResponse,
    ]
    """Retrieves the list of DNS zones in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.CreateDnsZoneRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a DNS zone in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateDnsZoneRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified DNS zone."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.DeleteDnsZoneRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified DNS zone."""

    GetRecordSet: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.GetDnsZoneRecordSetRequest,
        yandex.cloud.dns.v1.dns_zone_pb2.RecordSet,
    ]
    """Returns the specified record set."""

    ListRecordSets: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneRecordSetsRequest,
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneRecordSetsResponse,
    ]
    """Retrieves the list of record sets in the specified folder."""

    UpdateRecordSets: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateRecordSetsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Method with strict control for changing zone state. Returns error when:
    1. Deleted record is not found.
    2. Found record with matched type and name but different TTL or value.
    3. Attempted to add record with existing name and type.
    Deletions happen first. If a record with the same name and type exists in both lists,
    then the existing record will be deleted, and a new one added.
    """

    UpsertRecordSets: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpsertRecordSetsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Method without strict control for changing zone state. Nothing happens if deleted record doesn't exist.
    Deletes records that match all specified fields which allows to delete only specified records from a record set.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneOperationsRequest,
        yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneOperationsResponse,
    ]
    """Lists operations for the specified DNS zone."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified DNS zone."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified DNS zone."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified DNS zone."""

    UpdatePrivateNetworks: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateDnsZonePrivateNetworksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Atomically updates zone private networks"""

class DnsZoneServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing DNS zones."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.GetDnsZoneRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dns.v1.dns_zone_pb2.DnsZone, collections.abc.Awaitable[yandex.cloud.dns.v1.dns_zone_pb2.DnsZone]]:
        """Returns the specified DNS zone.

        To get the list of all available DNS zones, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZonesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZonesResponse, collections.abc.Awaitable[yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZonesResponse]]:
        """Retrieves the list of DNS zones in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.CreateDnsZoneRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a DNS zone in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateDnsZoneRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified DNS zone."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.DeleteDnsZoneRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified DNS zone."""

    @abc.abstractmethod
    def GetRecordSet(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.GetDnsZoneRecordSetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet, collections.abc.Awaitable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]]:
        """Returns the specified record set."""

    @abc.abstractmethod
    def ListRecordSets(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneRecordSetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneRecordSetsResponse, collections.abc.Awaitable[yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneRecordSetsResponse]]:
        """Retrieves the list of record sets in the specified folder."""

    @abc.abstractmethod
    def UpdateRecordSets(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateRecordSetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Method with strict control for changing zone state. Returns error when:
        1. Deleted record is not found.
        2. Found record with matched type and name but different TTL or value.
        3. Attempted to add record with existing name and type.
        Deletions happen first. If a record with the same name and type exists in both lists,
        then the existing record will be deleted, and a new one added.
        """

    @abc.abstractmethod
    def UpsertRecordSets(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.UpsertRecordSetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Method without strict control for changing zone state. Nothing happens if deleted record doesn't exist.
        Deletes records that match all specified fields which allows to delete only specified records from a record set.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneOperationsResponse, collections.abc.Awaitable[yandex.cloud.dns.v1.dns_zone_service_pb2.ListDnsZoneOperationsResponse]]:
        """Lists operations for the specified DNS zone."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified DNS zone."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified DNS zone."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified DNS zone."""

    @abc.abstractmethod
    def UpdatePrivateNetworks(
        self,
        request: yandex.cloud.dns.v1.dns_zone_service_pb2.UpdateDnsZonePrivateNetworksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Atomically updates zone private networks"""

def add_DnsZoneServiceServicer_to_server(servicer: DnsZoneServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Backup(google.protobuf.message.Message):
    """A ClickHouse Backup resource. See the [Developer's Guide](/docs/managed-clickhouse/concepts)
    for more information.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BackupType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BackupTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Backup._BackupType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BACKUP_TYPE_UNSPECIFIED: Backup._BackupType.ValueType  # 0
        AUTOMATED: Backup._BackupType.ValueType  # 1
        """Backup created by automated daily schedule."""
        MANUAL: Backup._BackupType.ValueType  # 2
        """Backup created by user request."""

    class BackupType(_BackupType, metaclass=_BackupTypeEnumTypeWrapper): ...
    BACKUP_TYPE_UNSPECIFIED: Backup.BackupType.ValueType  # 0
    AUTOMATED: Backup.BackupType.ValueType  # 1
    """Backup created by automated daily schedule."""
    MANUAL: Backup.BackupType.ValueType  # 2
    """Backup created by user request."""

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    SOURCE_CLUSTER_ID_FIELD_NUMBER: builtins.int
    SOURCE_SHARD_NAMES_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the backup."""
    folder_id: builtins.str
    """ID of the folder that the backup belongs to."""
    source_cluster_id: builtins.str
    """ID of the ClickHouse cluster that the backup was created for."""
    size: builtins.int
    """Size of backup in bytes."""
    type: global___Backup.BackupType.ValueType
    """How this backup was created (manual/automatic/etc...)."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format
        (i.e. when the backup operation was completed).
        """

    @property
    def source_shard_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of the shards included in the backup."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the backup operation was started."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        source_cluster_id: builtins.str = ...,
        source_shard_names: collections.abc.Iterable[builtins.str] | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        size: builtins.int = ...,
        type: global___Backup.BackupType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "folder_id", b"folder_id", "id", b"id", "size", b"size", "source_cluster_id", b"source_cluster_id", "source_shard_names", b"source_shard_names", "started_at", b"started_at", "type", b"type"]) -> None: ...

global___Backup = Backup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.serverless.workflows.v1.execution_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ExecutionServiceStub:
    """Set of methods for managing Workflows Executions."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StartExecutionRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StartExecutionResponse,
    ]
    """Starts new Workflow execution."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StopExecutionRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StopExecutionResponse,
    ]
    """Stops specified Workflow execution."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionResponse,
    ]
    """Retrieves specified Workflow execution."""

    GetHistory: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionHistoryRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionHistoryResponse,
    ]
    """Retrieves detailed history of specified Workflow execution."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.ListExecutionsRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.ListExecutionsResponse,
    ]
    """Retrieves list of Workflow executions."""

class ExecutionServiceAsyncStub:
    """Set of methods for managing Workflows Executions."""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StartExecutionRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StartExecutionResponse,
    ]
    """Starts new Workflow execution."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StopExecutionRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.StopExecutionResponse,
    ]
    """Stops specified Workflow execution."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionResponse,
    ]
    """Retrieves specified Workflow execution."""

    GetHistory: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionHistoryRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionHistoryResponse,
    ]
    """Retrieves detailed history of specified Workflow execution."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.ListExecutionsRequest,
        yandex.cloud.serverless.workflows.v1.execution_service_pb2.ListExecutionsResponse,
    ]
    """Retrieves list of Workflow executions."""

class ExecutionServiceServicer(metaclass=abc.ABCMeta):
    """Set of methods for managing Workflows Executions."""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.serverless.workflows.v1.execution_service_pb2.StartExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.execution_service_pb2.StartExecutionResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.execution_service_pb2.StartExecutionResponse]]:
        """Starts new Workflow execution."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.serverless.workflows.v1.execution_service_pb2.StopExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.execution_service_pb2.StopExecutionResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.execution_service_pb2.StopExecutionResponse]]:
        """Stops specified Workflow execution."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionResponse]]:
        """Retrieves specified Workflow execution."""

    @abc.abstractmethod
    def GetHistory(
        self,
        request: yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionHistoryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionHistoryResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.execution_service_pb2.GetExecutionHistoryResponse]]:
        """Retrieves detailed history of specified Workflow execution."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.serverless.workflows.v1.execution_service_pb2.ListExecutionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.execution_service_pb2.ListExecutionsResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.execution_service_pb2.ListExecutionsResponse]]:
        """Retrieves list of Workflow executions."""

def add_ExecutionServiceServicer_to_server(servicer: ExecutionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/mdb/sqlserver/v1/user.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1dyandex/cloud/validation.proto\"\xa9\x01\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12>\n\x0bpermissions\x18\x03 \x03(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.Permission\x12?\n\x0cserver_roles\x18\x04 \x03(\x0e\x32).yandex.cloud.mdb.sqlserver.v1.ServerRole\"\xbe\x02\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x46\n\x05roles\x18\x02 \x03(\x0e\x32..yandex.cloud.mdb.sqlserver.v1.Permission.RoleB\x07\x82\xc8\x31\x03>=1\"\xd0\x01\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44\x42_OWNER\x10\x01\x12\x14\n\x10\x44\x42_SECURITYADMIN\x10\x02\x12\x12\n\x0e\x44\x42_ACCESSADMIN\x10\x03\x12\x15\n\x11\x44\x42_BACKUPOPERATOR\x10\x04\x12\x0f\n\x0b\x44\x42_DDLADMIN\x10\x05\x12\x11\n\rDB_DATAWRITER\x10\x06\x12\x11\n\rDB_DATAREADER\x10\x07\x12\x15\n\x11\x44\x42_DENYDATAWRITER\x10\x08\x12\x15\n\x11\x44\x42_DENYDATAREADER\x10\t\"\xd9\x01\n\x08UserSpec\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=32\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12>\n\x0bpermissions\x18\x03 \x03(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.Permission\x12?\n\x0cserver_roles\x18\x04 \x03(\x0e\x32).yandex.cloud.mdb.sqlserver.v1.ServerRole*:\n\nServerRole\x12\x1b\n\x17SERVER_ROLE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bMDB_MONITOR\x10\x01\x42u\n!yandex.cloud.api.mdb.sqlserver.v1B\x03PSUZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\003PSUZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _PERMISSION.fields_by_name['roles']._options = None
  _PERMISSION.fields_by_name['roles']._serialized_options = b'\202\3101\003>=1'
  _USERSPEC.fields_by_name['name']._options = None
  _USERSPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=32'
  _USERSPEC.fields_by_name['password']._options = None
  _USERSPEC.fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_SERVERROLE']._serialized_start=819
  _globals['_SERVERROLE']._serialized_end=877
  _globals['_USER']._serialized_start=107
  _globals['_USER']._serialized_end=276
  _globals['_PERMISSION']._serialized_start=279
  _globals['_PERMISSION']._serialized_end=597
  _globals['_PERMISSION_ROLE']._serialized_start=389
  _globals['_PERMISSION_ROLE']._serialized_end=597
  _globals['_USERSPEC']._serialized_start=600
  _globals['_USERSPEC']._serialized_end=817
# @@protoc_insertion_point(module_scope)
